summaryrefslogtreecommitdiff
path: root/xmake/modules/detect/tools/find_sdcc.lua
diff options
context:
space:
mode:
authorruki <[email protected]>2020-09-25 00:50:35 +0800
committerruki <[email protected]>2020-09-25 00:50:35 +0800
commit475233c8d4ca369e967c102558068392c9e496e8 (patch)
tree7c545db4f3dfe5a30891b538659e7893f1af446e /xmake/modules/detect/tools/find_sdcc.lua
parentba3a8eba461121eed5028f3e1f5c426fda348637 (diff)
rename some pathes to paths
Diffstat (limited to 'xmake/modules/detect/tools/find_sdcc.lua')
-rw-r--r--xmake/modules/detect/tools/find_sdcc.lua12
1 files changed, 6 insertions, 6 deletions
diff --git a/xmake/modules/detect/tools/find_sdcc.lua b/xmake/modules/detect/tools/find_sdcc.lua
index a6f7bbd8b..5c2867d02 100644
--- a/xmake/modules/detect/tools/find_sdcc.lua
+++ b/xmake/modules/detect/tools/find_sdcc.lua
@@ -40,17 +40,17 @@ function main(opt)
opt = opt or {}
opt.command = opt.command or "--version"
- -- add search pathes
- local pathes = {}
+ -- add search paths
+ local paths = {}
local bindir = get_config("bin")
if bindir and os.isdir(bindir) then
- table.insert(pathes, bindir)
+ table.insert(paths, bindir)
end
if is_host("windows") then
- table.insert(pathes, "$(reg HKEY_LOCAL_MACHINE\\SOFTWARE\\WOW6432Node\\SDCC)\\bin")
+ table.insert(paths, "$(reg HKEY_LOCAL_MACHINE\\SOFTWARE\\WOW6432Node\\SDCC)\\bin")
end
- if #pathes > 0 then
- opt.pathes = pathes
+ if #paths > 0 then
+ opt.pathes = paths
end
-- find program